@@ -49,7 +49,7 @@ import csv
 
 @login_required
 def index(request):
-    return render(request,'index.html',{})
+    return render(request,'celex/index.html',{})
 
 
 @login_required
@@ -63,10 +63,10 @@ def reset(request):
                 return redirect(index)
             else:
                 form = ResetForm()
-                render(request,'reset.html',{'form':form})
+                render(request,'celex/form.html',{'form':form})
         else:
             form = ResetForm()
-            return render(request,'reset.html',{'form':form})
+            return render(request,'celex/form.html',{'form':form})
 
 #def getFreqBreaks(qs):
     #freqs = sorted(qs.values_list('Frequency',flat=True))
